from typing import Optional, TypedDict, Union


class SFTPServer(TypedDict):
    r"""
- Contains connection details for an SFTP server

- The example below shows the dictionary structure in YAML

!!! warning "Supplying Credentials"

    You should ___always___ use a PPA Vault integration to provide credentials to a plugin action.

!!! example

    ```yaml linenums="1"
    sftp_server:
      address: 1.2.3.4
      port: 22
      username: [username]
      password: [password]
    ```

???+ danger "Required Keys"

    __address__: The target IP or DNS address.

    __port__: The target SFTP port.

    __username__: Username for authentication.

    __password__: Password for authentication.

    """
    address: str
    port: Union[str, int]
    username: str
    password: str


class DirectoryItem(TypedDict):
    """
- Contains information about files and directories present on the SFTP server

!!! info "All DirectoryItem Keys"

    __name__: The name of the item.

    __is_dir__: Denotes whether the item is a directory.

    __size__: Size of the item in bytes.

    __last_modified__: Date (UTC) the item was last modified.

!!! example "YAML Structure"

    ```yaml linenums="1"
    name: randomfile.txt
    is_dir: false
    size: 20
    last_modified: "17:05 10/02/2021"
    ```
    """

    name: str
    is_dir: Optional[bool]
    size: Optional[int]
    last_modified: Optional[str]
